@@ -3,17 +3,18 @@ import logging
 import os
 
 from pyage.core import address
+
 from pyage.core.agent.agent import unnamed_agents
 from pyage.core.agent.aggregate import AggregateAgent
 from pyage.core.emas import EmasService
-from pyage.core.locator import  GridParentLocator
-from pyage.core.migration import  ParentMigration
-from pyage.core.stats.gnuplot import TimeStatistics, StepStatistics
+from pyage.core.locator import GridLocator
+from pyage.core.migration import ParentMigration
+from pyage.core.stats.gnuplot import StepStatistics
 from pyage.core.stop_condition import StepLimitStopCondition
-from pyage.solutions.evolution.crossover import   SinglePointCrossover
-from pyage.solutions.evolution.evaluation import  FloatRastriginEvaluation
-from pyage.solutions.evolution.initializer import  float_emas_initializer
-from pyage.solutions.evolution.mutation import  UniformFloatMutation
+from pyage.solutions.evolution.crossover import SinglePointCrossover
+from pyage.solutions.evolution.evaluation import FloatRastriginEvaluation
+from pyage.solutions.evolution.initializer import float_emas_initializer
+from pyage.solutions.evolution.mutation import UniformFloatMutation
 
 
 logger = logging.getLogger(__name__)
@@ -41,7 +42,6 @@ mutation = lambda: UniformFloatMutation(probability=1, radius=1)
 address_provider = address.SequenceAddressProvider
 
 migration = ParentMigration
-locator = GridParentLocator
+locator = GridLocator
 
-
-stats = StepStatistics
\ No newline at end of file
+stats = lambda: StepStatistics('fitness_%s_pyage.txt' % __name__)
